# Authors

Project is part of the [MAS programme in Architecture and Digital Fabrication](https://www.masdfab.com/) taught at ETH Zürich by [Gramazio Kohler Research](https://gramaziokohler.arch.ethz.ch/) and [Digital Building Technologies](https://dbt.arch.ethz.ch/).

## Students

* Fatemeh Amiri
* Jomana Baddad
* Frédéric Brisson [github](https://github.com/FredETH2019/) [email](mailto:frbrisson@hotmail.com)
* YuHung Chiu
* Ioulios Georgiou [github](https://github.com/iouliosG/)
* Mahiro Goto
* Anton T Johansson [github](https://github.com/tetov/) [email](mailto:anton@tetov.se)
* László Mangliár [github](https://github.com/railgnam/)
* Dinorah Martinez Schulte
* Edurne Morales [github](https://github.com/edurnemorales/)
* Maria Pia
* Emmanuelle Sallin [github](https://github.com/esallin/)
* Indra Santosa [github](https://github.com/isantosa/)
* Eliott Sounigo
* Clemente Rémy [github](https://github.com/clementeremy/)
* Chanon Techathuvanun [github](https://github.com/ctechathuvanun/)
* Psing-Hsun Tsai [github](https://github.com/PingHsunTsai/)

## Tutors

* David Jenny [github](https://github.com/DavidJenny/)  [email](mailto:david.jenny@arch.ethz.ch)
* Nicolas Feihl [email](mailto:feihl@arch.ethz.ch)
* Coralie Ming [email](mailto:ming@arch.ethz.ch)

## Collaborators

* Gonzalo Casas [github](https://github.com/gonzalocasas) [email](mailto:casas@arch.ethz.ch) software engineer, Gramazio Kohler Research
* Philippe Fleischmann [email](mailto:fleischmann@dfab.ch) robot technician, NCCR Digital Fabrication
